# Code of Conduct

This project follows the Contributor Covenant Code of Conduct.

## Our pledge

We pledge to make participation in our community a harassment-free experience for everyone.

## Our standards

Examples of behavior that contributes to a positive environment include:

- Being respectful and constructive
- Accepting feedback gracefully
- Focusing on what is best for the community

Examples of unacceptable behavior include:

- Harassment, personal attacks, or discriminatory language
- Trolling or insulting comments

## Enforcement

Project maintainers are responsible for clarifying standards of acceptable behavior and will take appropriate action.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.1:
https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
